@@ -63,12 +63,12 @@ class TaskDaemon(object):
                             "loglevel": self.loglevel}
         task_func_params.update(message_data)
 
-        #try:
-        result = self.pool.apply_async(task_func, [], task_func_params)
-        #except:
-        #    message.reject()
-        #    raise
-
+        try:
+            result = self.pool.apply_async(task_func, [], task_func_params)
+        except Exception, error:
+            self.logger.critical("Worker got exception %s: %s\n%s" % (
+                error.__class__, error, traceback.format_exc()))
+            return 
 
         message.ack()
         return result, task_name, task_id
@@ -86,6 +86,10 @@ class TaskDaemon(object):
             self.run_periodic_tasks()
             try:
                 result, task_name, task_id = self.fetch_next_task()
+            except ValueError:
+                # fetch_next_task didn't return a r/name/id tuple,
+                # probably because it got an exception.
+                continue
             except EmptyQueue:
                 if not last_empty_emit or \
                         time.time() > last_empty_emit + EMPTY_MSG_EMIT_EVERY:
@@ -94,12 +98,11 @@ class TaskDaemon(object):
                 time.sleep(self.queue_wakeup_after)
                 continue
             except UnknownTask, e:
-                self.logger.info("Unknown task requeued and ignored: %s" % (
-                                    e))
+                self.logger.info("Unknown task ignored: %s" % (e))
+                continue
+            except Exception, e:
+                self.logger.critical("Message queue raised %s: %s\n%s" % (
+                             e.__class__, e, traceback.format_exc()))
                 continue
-            #except Exception, e:
-            #    self.logger.critical("Raised %s: %s\n%s" % (
-            #                 e.__class__, e, traceback.format_exc()))
-            #    continue
            
             results.add(result, task_name, task_id)
